@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2017 Rumma & Ko Ltd
+# Copyright 2017-2020 Rumma & Ko Ltd
 # License: BSD (see file COPYING for details)
 
 """
@@ -16,9 +16,6 @@
 
 """
 
-from __future__ import print_function
-from __future__ import unicode_literals
-
 from lino.projects.std.settings import *
 from lino.api.ad import _
 
@@ -64,6 +61,7 @@ class Site(Site):
         yield 'lino.modlib.comments'
         yield 'lino.modlib.notify'
         yield 'lino.modlib.changes'
+        yield 'lino_xl.lib.clients'
         yield 'lino_xl.lib.uploads'
         yield 'lino.modlib.dupable'
         # yield 'lino_xl.lib.households'
@@ -73,7 +71,6 @@ class Site(Site):
         yield 'lino_xl.lib.lists'
         # yield 'lino_xl.lib.notes'
         yield 'lino_xl.lib.beid'
-        yield 'lino_xl.lib.clients'
         yield 'lino_avanti.lib.cv'
         yield 'lino_xl.lib.trends'
         yield 'lino_xl.lib.polls'
@@ -124,7 +121,10 @@ class Site(Site):
         yield ('cv', 'person_model', 'avanti.Client')
         yield ('cal', 'partner_model', 'avanti.Client')
         yield ('clients', 'client_model', 'avanti.Client')
+        yield ('clients', 'demo_coach', 'nathalie')
         yield ('trends', 'subject_model', 'avanti.Client')
+        yield ('uploads', 'expiring_start', -30)
+        yield ('uploads', 'expiring_end', 365)
 
     def setup_quicklinks(self, user, tb):
         super(Site, self).setup_quicklinks(user, tb)
